@@ -1,12 +1,14 @@
 #![allow(dead_code)]
 
+use std::cell::RefCell;
+
 use ts_rs::TS;
 
 #[derive(TS)]
 struct Simple {
     a: i32,
     b: String,
-    c: (i32, String, i32),
+    c: (i32, String, RefCell<i32>),
     d: Vec<String>,
     e: Option<String>,
 }
